@@ -14,6 +14,8 @@ if TYPE_CHECKING:
     from alpha_trader.user import User
     from alpha_trader.securities_account import SecuritiesAccount
     from alpha_trader.bonds import Bond
+    from alpha_trader.company import Company
+    from alpha_trader.order import Order
 
 from alpha_trader.logging import logger
 
@@ -242,5 +244,66 @@ class Client(BaseModel):
 
         return Bond.initialize_from_api_response(response.json(), client=self, price_spread=price_spread)
 
+    def get_company(self, security_identifier: str) -> Company:
+        """
+            Get the company information for a security.
+
+        Args:
+            security_identifier: Security identifier
+
+        Returns:
+            Company
+        """
+        from alpha_trader.company import Company
+
+        response = self.request("GET", f"api/companies/securityIdentifier/{security_identifier}")
+
+        return Company.initialize_from_api_response(response.json(), client=self)
+
+    def get_order(self, order_id: str) -> Order:
+        """
+            Get the order information for a given order ID.
+
+        Args:
+            order_id: Order ID
+
+        Returns:
+            Order
+        """
+        from alpha_trader.order import Order
+
+        response = self.request("GET", f"api/securityorders//{order_id}")
+
+        return Order.initialize_from_api_response(response.json(), client=self)
+
     def get_bonds(self, page: int, search: str, page_size: int):
         pass
+
+    def register_user(self, username: str, password: str, email: str, locale: str = None) -> User:
+        """
+            Register a new user
+        Args:
+            username: Username
+            password: Password
+            email: Email
+            locale: Locale
+
+        Returns:
+            User
+        """
+        from alpha_trader.user import User
+
+        data = {
+            "username": username,
+            "password": password,
+            "emailAddress": email,
+            "locale": locale,
+        }
+
+        response = requests.post(f"{self.base_url}/user/register", data=data)
+        if response.status_code != 201:
+            raise Exception(response.text)
+
+        self.login()
+
+        return User.initialize_from_api_response(response.json(), self)
